@@ -3,7 +3,7 @@ package CohortExplorer::Command::Query::Search;
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.06;
 
 use base qw(CohortExplorer::Command::Query);
 use CLI::Framework::Exceptions qw( :all );
@@ -30,9 +30,9 @@ sub usage_text {    # Command is available to both standard and longitudinal dat
 
 
               EXAMPLES
-                 search --out /home/user/exports --stats --save-command --cond CER.Score="{'<=','30'}" SC.Date
+                 search --out=/home/user/exports --stats --save-command --cond=CER.Score="{'<=','30'}" SC.Date
 
-                 search --out /home/user/exports --export-all --cond SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
+                 search --out=/home/user/exports --export-all --cond=SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
 
                  search -o /home/user/exports -e DS -e SD -c Entity_ID="{'like',['SUB100%','SUB200%']}" DIS.Status
 
@@ -260,7 +260,7 @@ __END__
 
 =head1 NAME
 
-CohortExplorer::Command::Query::Search - CohortExplorer class to search entities with or without conditions on variables
+CohortExplorer::Command::Query::Search - CohortExplorer class to search entities
 
 =head1 SYNOPSIS
 
@@ -330,9 +330,9 @@ The variables C<Entity_ID> and C<Visit> (if applicable) must not be provided as
 
 =head1 EXAMPLES
 
- search --out /home/user/exports --stats --save-command --cond DS.Status="{'=','CTL'}" SC.Date
+ search --out=/home/user/exports --stats --save-command --cond=DS.Status="{'=','CTL'}" SC.Date
 
- search --out /home/user/exports --export-all --cond SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
+ search --out=/home/user/exports --export-all --cond=SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
 
  search -o /home/user/exports -e DS -e SD -c Entity_ID="{'like',['SUB100%','SUB200%']}" DIS.Status
 
